# frozen_string_literal: true

require 'test_helper'

describe BridgeAPI::Client::SubAccount do
  before do
    @client = BridgeAPI::Client.new(
      prefix: 'http://test.bridge.com',
      token: 'test_token'
    )
  end

  it 'should get all subaccounts' do
    response = @client.get_sub_accounts
    expect(response.first['id']).to(eq('141'))
  end

  it 'should get a single subaccount' do
    subaccounts = @client.get_sub_account(1)
    expect(subaccounts.count).to(eq(1))
    expect(subaccounts.first['name']).to(eq('Customers'))
  end

  it 'should activate a subaccount' do
    response = @client.activate_sub_account(1)
    expect(response.first['id']).to(eq('141'))
  end

  it 'should deactivate a subaccount' do
    response = @client.deactivate_sub_account(1)
    expect(response.first['id']).to(eq('141'))
  end

  it 'should get all the lti config' do
    response = @client.get_lti_config_for_sub_account(1)
    expect(response.body['lti_tools'].first['id']).to(eq('100'))
  end

  it 'should update the lti config' do
    params = { lti_tool: { consumer_key: 'YoooKey', shared_secret: SecureRandom.hex(16) } }
    response = @client.update_sub_account_lti_config(2, 15, params)
    expect(response.body['lti_tool']['id']).to(eq '20')
  end

  it 'should create new lti config' do
    params = { lti_tool: { consumer_key: 'SomeKey', shared_secret: SecureRandom.hex(16) } }
    response = @client.create_sub_account_lti_config(2, params)
    expect(response.status).to(eq 201)
  end

  it 'should delete a lti config' do
    response = @client.delete_lti_config(2, 15)
    expect(response.status).to(eq 204)
  end

  it 'should upsert the custom attribute values of a sub account' do
    params = {
      custom_attributes: [
        {
          product_type: 'YoooKey',
          client_type: 'SomeKey'
        },
      ]
    }
    response = @client.upsert_custom_attribute_values(2, params)
    expect(response.status).to(eq 200)
  end
end
