# frozen_string_literal: true

require 'test_helper'

describe BridgeAPI::Client::User do
  before do
    @client = BridgeAPI::Client.new(prefix: 'http://test.bridge.com', token: 'test_token')
  end

  it 'should add an user' do
    response = @client.add_user
    expect(response.first['id']).to(eq('10'))
  end

  it 'should get a user' do
    response = @client.get_user(1)
    expect(response.first['id']).to(eq('10'))
  end

  it 'should delete an user' do
    response = @client.delete_user(1)
    expect(response.status).to(eq(204))
  end

  it 'should update a user' do
    response = @client.update_user(1)
    expect(response.first['id']).to(eq('10'))

    response = @client.update_user_with_custom_values(1, '1' => 'test')
    expect(response.first['id']).to(eq('10'))
  end

  it 'should get all users' do
    response = @client.get_all_users
    expect(response.length).to(eq(2))
  end

  it 'should add roles by batch for a user' do
    response = @client.add_user_to_role_batch(1)
    expect(response.length).to eq(7)
  end

  it 'should get new temporary users' do
    response = @client.new_temporary_users
    expect(response.length).to(eq(2))
  end
end
