# frozen_string_literal: true

require 'sinatra/base'
require 'tilt'

class FakeBridge < Sinatra::Base
  ## Clone Objects

  post %r{/api/admin/clone_objects$} do
    get_json_data 200, 'clone_objects.json'
  end

  get %r{/api/admin/clone_objects/\d+$} do
    get_json_data 200, 'clone_objects.json'
  end

  ## Course Templates

  get %r{/api/author/course_templates$} do
    get_json_data 200, 'courses.json'
  end

  get %r{/api/author/course_templates/\d+$} do
    get_json_data 200, 'course.json'
  end

  post %r{/api/author/course_templates$} do
    get_json_data 200, 'course.json'
  end

  post %r{/api/author/course_templates/\d+/publish$} do
    get_json_data 200, 'course.json'
  end

  put %r{/api/author/course_templates/\d+$} do
    get_json_data 200, 'course.json'
  end

  delete %r{/api/author/course_templates/\d+$} do
    get_json_data 204, nil
  end

  ## Programs

  get %r{/api/author/programs.*$} do
    get_json_data 200, 'programs.json'
  end

  ## Program enrollments

  get %r{/api/author/programs/\d+/learners} do
    get_json_data 200, 'program_enrollments.json'
  end

  put %r{/api/author/programs/\d+/learners/\d+} do
    get_json_data 200, 'program_enrollments.json'
  end

  post %r{/api/author/programs/\d+/learners} do
    get_json_data 204, nil
  end

  post %r{/api/author/programs/\d+/completions} do
    get_json_data 204, nil
  end

  delete %r{/api/author/programs/\d+/learners} do
    get_json_data 204, nil
  end

  ## Users

  get %r{/api/author/users$} do
    response.headers['x-rate-limit-remaining'] = 29
    get_json_data 200, 'users.json'
  end

  get %r{/api/author/users/\d+$} do
    get_json_data 200, 'user.json'
  end

  put %r{/api/author/users/\d+$} do
    get_json_data 200, 'user.json'
  end

  post %r{/api/admin/users$} do
    get_json_data 200, 'user.json'
  end

  delete %r{/api/admin/users/\d+$} do
    get_json_data 204, nil
  end

  get %r{/api/admin/new_temporary_users} do
    get_json_data 200, 'temporary_users.json'
  end

  ## Managers
  get %r{/api/author/managers$} do
    get_json_data 200, 'managers.json'
  end

  get %r{/api/author/managers/\d+/direct_reports$} do
    get_json_data 200, 'direct_reports.json'
  end

  ## Enrollments

  post %r{/api/author/course_templates/\d+/enrollments$} do
    get_json_data 204, nil
  end

  get %r{/api/author/course_templates/\d+/enrollments$} do
    get_json_data 200, 'enrollments.json'
  end

  delete %r{/api/author/enrollments.*$} do
    get_json_data 204, nil
  end

  put %r{/api/author/enrollments.*$} do
    get_json_data 200, 'enrollment.json'
  end

  post %r{/api/author/enrollments/\d+/due_date$} do
    get_json_data 200, 'enrollment.json'
  end

  post %r{/api/admin/enrollments/\d+/reset} do
    get_json_data 204, 'enrollment.json'
  end

  get %r{/api/author/learners/\d+/learner_enrollments$} do
    get_json_data 200, 'learner_enrollments.json'
  end

  # Custom Fields

  get %r{/api/author/custom_fields} do
    get_json_data 200, 'custom_fields.json'
  end

  get %r{/api/author/custom_fields/\d+$} do
    get_json_data 200, 'custom_fields.json'
  end

  put %r{/api/author/custom_fields/\d+$} do
    get_json_data 200, 'custom_fields.json'
  end

  post %r{/api/author/custom_fields} do
    get_json_data 200, 'custom_fields.json'
  end

  delete %r{/api/author/custom_fields/\d+$} do
    get_json_data 204, nil
  end

  # Data Dumps

  get %r{/api/admin/data_dumps} do
    get_json_data 200, 'data_dumps.json'
  end

  post %r{/api/admin/data_dumps} do
    get_json_data 200, 'data_dump.json'
  end

  get %r{/api/admin/data_dumps/download} do
    get_json_data 200, nil
  end

  # Groups

  post %r{/api/author/groups} do
    get_json_data 201, 'group.json'
  end

  put %r{/api/author/groups/\d+$} do
    get_json_data 200, 'group.json'
  end

  # Learner Items
  get %r{/api/author/learners/\d+/learner_items$} do
    get_json_data 200, 'learner_items.json'
  end

  # Live Courses
  get %r{/api/author/live_courses$} do
    get_json_data 200, 'live_courses.json'
  end

  get %r{/api/author/live_courses/\d+$} do
    get_json_data 200, 'live_course.json'
  end

  # Live Course Enrollments
  get %r{/api/author/live_courses/\d+/learners} do
    get_json_data 200, 'live_course_enrollments.json'
  end

  # Web Conference
  get %r{/api/author/web_conference$} do
    get_json_data 200, 'default_web_conference.json'
  end

  # Live Course Sessions
  post %r{/api/author/live_courses/\d+/sessions/\d+/publish} do
    get_json_data 200, 'live_course_sessions.json'
  end

  get %r{/api/author/live_courses/\d+/sessions} do
    get_json_data 201, 'live_course_sessions.json'
  end

  get %r{/api/author/live_courses/\d+/sessions/\d+} do
    get_json_data 201, 'live_course_sessions.json'
  end

  post %r{/api/author/live_courses/\d+/sessions} do
    get_json_data 201, 'live_course_sessions.json'
  end

  delete %r{/api/author/live_courses/\d+/sessions/\d+} do
    get_json_data 204, 'live_course_sessions.json'
  end

  put %r{/api/author/live_courses/\d+/sessions} do
    get_json_data 200, 'live_course_sessions.json'
  end

  # Sub Accounts
  post %r{/api/admin/sub_accounts$} do
    get_json_data 200, 'sub_accounts.json'
  end

  get %r{/api/admin/sub_accounts$} do
    get_json_data 200, 'sub_accounts.json'
  end

  get %r{/api/admin/sub_accounts/\d+$} do
    get_json_data 200, 'sub_accounts.json'
  end

  put %r{/api/admin/sub_accounts$} do
    get_json_data 200, 'sub_accounts.json'
  end

  put %r{/api/admin/sub_accounts/\d+/disable} do
    get_json_data 200, 'sub_accounts.json'
  end

  put %r{/api/admin/sub_accounts/\d+/enable} do
    get_json_data 200, 'sub_accounts.json'
  end

  get %r{/api/support/sub_accounts/\d+/lti_tools} do
    get_json_data 200, 'sub_account_lti_config.json'
  end

  put %r{/api/support/sub_accounts/\d+/lti_tools/\d+} do
    get_json_data 200, 'sub_account_lti_config_update.json'
  end

  post %r{/api/support/sub_accounts/\d+/lti_tools} do
    get_json_data 201, 'sub_account_new_lti_config.json'
  end

  delete %r{/api/support/sub_accounts/\d+/lti_tools/\d+} do
    get_json_data 204, 'sub_account_lti_config.json'
  end

  put %r{/api/admin/sub_accounts/\d+/custom_attribute_values} do
    get_json_data 200, 'custom_attribute_values.json'
  end

  # Accounts
  put %r{/api/support/accounts} do
    get_json_data 200, 'accounts.json'
  end

  # Roles
  get %r{/api/author/roles} do
    get_json_data 200, 'roles.json'
  end

  post %r{/api/author/roles} do
    get_json_data 200, 'roles.json'
  end

  put %r{/api/admin/users/\d+/roles} do
    get_json_data 200, 'user_roles_add.json'
  end

  delete %r{/api/author/roles} do
    get_json_data 204, 'roles.json'
  end

  # Affiliations
  get %r{/api/author/affiliated_sub_accounts} do
    get_json_data 204, 'affiliations.json'
  end

  put %r{/api/author/affiliated_sub_accounts} do
    get_json_data 204, 'affiliations.json'
  end

  private

  def get_json_data(response_code, file_name)
    content_type :json
    status response_code
    if file_name.nil?
      {}
    else
      File.open(File.dirname(__FILE__) + '/../fixtures/' + file_name).read
    end
  end
end
